@@ -48,7 +48,7 @@ class RegionEstimator(object):
         """
         ### Check sensors:
 
-        #assert sensors.index.name == 'sensor_id', "sensors dataframe index name must be 'sensor_id'"
+        assert sensors.index.name == 'sensor_id', "sensors dataframe index name must be 'sensor_id'"
         # (Not checking sensor_id data as that forms the index)
         assert 'latitude' in list(sensors.columns), "There is no latitude column in sensors dataframe"
         assert pd.to_numeric(sensors['latitude'], errors='coerce').notnull().all(), \
